@@ -1,11 +1,24 @@
 <?php
 /*
+
  +-----------------------------------------------------------------------+
  | Domain Hunter - A Simple Domain Monitoring Application                |
- | Version 0.1.0                                                         |
+ | Version 0.1.2                                                         |
  |                                                                       |
- | Copyright (C) 2006-2007, DomainLabs.EU - Turkey                       |
- | Licensed under the GNU GPLv3                                          |
+ | Copyright (C) 2006-2015, Bahri.Info - Turkey                          |
+ |									 | 
+ | This program is free software: you can redistribute it and/or modify  |
+ | it under the terms of the GNU General Public License as published by  |
+ | the Free Software Foundation, either version 3 of the License, or     |
+ | (at your option) any later version.					 |
+ |									 |
+ | This program is distributed in the hope that it will be useful,	 |
+ | but WITHOUT ANY WARRANTY; without even the implied warranty of	 |
+ | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	 |
+ | GNU General Public License for more details.				 |
+ |									 |
+ | You should have received a copy of the GNU General Public License	 |
+ | along with this program.  If not, see <http://www.gnu.org/licenses/>. |                                     |
  |                                                                       |
  +-----------------------------------------------------------------------+
  | Author: Bahri Meric CANLI <bahri@bahri.info>                          |
@@ -27,7 +40,7 @@
 <table>
 <tr>
 <td>
-<img id="login_header_logo" src="huntertext.gif" />
+<img src="domainhunter.png" width="250px" height="100px" border="0" />
 </td>
 <td>
 &nbsp;
